"""
ANIAnimator makes the GIF file from a given chemical ANI file
"""
from __future__ import absolute_import

__title__ = "ANIAnimator"
__author__ = "Eftal Gezer"
__license__ = "GNU GPL v3"
__copyright__ = "Copyright 2022, Eftal Gezer"
__version__ = "0.1.0"

from .core import animate
